ARM register names...

Scott Bambrough scottb@netwinder.org
Tue Jun 13 07:49:00 GMT 2000


Hi Nick,

I'd like to propose the following patch to allow the tools to default to the
same register set that GCC uses by default.  Most of the assembly code in gcc,
glibc and bfd uses this register set, and I find dumps using the standard set a
little odd.

Scott

2000-06-13  Scott Bambrough <scottb@netwinder.org>

	* arm-dis.c (regnames): Add an additional register set to match the set used by
	gcc.  Make it the default.

Index: arm-dis.c
===================================================================
RCS file: /cvs/src/src/opcodes/arm-dis.c,v
retrieving revision 1.15.2.1
diff -u -p -r1.15.2.1 arm-dis.c
--- arm-dis.c   2000/05/30 13:42:11     1.15.2.1
+++ arm-dis.c   2000/06/13 14:38:02
@@ -60,6 +60,8 @@ static arm_regname regnames[] =
 {
   { "raw" , "Select raw register names",
     { "r0", "r1", "r2", "r3", "r4", "r5", "r6", "r7", "r8", "r9", "r10", "r11",
"r12", "r13", "r14", "r15"}},
+  { "gcc",  "Select register names used by GCC",
+    { "r0", "r1", "r2", "r3", "r4", "r5", "r6", "r7", "r8", "r9", "sl",  "fp", 
"ip",  "sp",  "lr",  "pc" }},
   { "std",  "Select register names used in ARM's ISA documentation",
     { "r0", "r1", "r2", "r3", "r4", "r5", "r6", "r7", "r8", "r9", "r10", "r11",
"r12", "sp",  "lr",  "pc" }},
   { "apcs", "Select register names used in the APCS",
@@ -70,7 +72,7 @@ static arm_regname regnames[] =
     { "a1", "a2", "a3", "a4", "v1", "v2", "v3", "WR", "v5", "SB", "SL",  "FP", 
"IP",  "SP",  "LR",  "PC" }}
 };
 
 /* Default to standard register name set.  */
 static unsigned int regname_selected = 1;
 
 #define NUM_ARM_REGNAMES  NUM_ELEM (regnames)
@@ -70,7 +72,7 @@ static arm_regname regnames[] =
 };
 
-/* Default to standard register name set.  */
+/* Default to GCC register name set.  */
 static unsigned int regname_selected = 1;
 
-- 
Scott Bambrough - Software Engineer
REBEL.COM    http://www.rebel.com
NetWinder    http://www.netwinder.org


More information about the Binutils mailing list